@@ -30,6 +30,7 @@
 #include "security/CredentialCriteria.h"
 #include "security/OpenSSLTrustEngine.h"
 #include "security/OpenSSLCredential.h"
+#include "security/impl/OpenSSLSupport.h"
 #include "soap/HTTPSOAPTransport.h"
 #include "soap/OpenSSLSOAPTransport.h"
 #include "util/NDC.h"
@@ -73,7 +74,7 @@ namespace xmltooling {
         CURLSOAPTransport(const Address& addr)
             : m_sender(addr.m_from ? addr.m_from : ""), m_peerName(addr.m_to ? addr.m_to : ""), m_endpoint(addr.m_endpoint),
                 m_handle(nullptr), m_keepHandle(false), m_headers(nullptr),
-#ifdef HAVE_CURLINFO_TLS_SSL_PTR
+#if HAVE_DECL_CURLINFO_TLS_SSL_PTR
                     m_cipherLogged(false),
 #endif
 #ifndef XMLTOOLING_NO_XMLSEC
@@ -117,6 +118,15 @@ namespace xmltooling {
             return (curl_easy_setopt(m_handle,CURLOPT_TIMEOUT,timeout)==CURLE_OK);
         }
 
+        bool setAcceptEncoding(const char *value)
+        {
+#if HAVE_DECL_CURLOPT_ACCEPT_ENCODING
+            return (curl_easy_setopt(m_handle, CURLOPT_ACCEPT_ENCODING, value) == CURLE_OK);
+#else
+            return (curl_easy_setopt(m_handle, CURLOPT_ENCODING, value) == CURLE_OK);
+#endif
+        }
+
         bool setAuth(transport_auth_t authType, const char* username=nullptr, const char* password=nullptr);
 
         bool setVerifyHost(bool verify) {
@@ -225,7 +235,7 @@ namespace xmltooling {
 		string m_useragent;
         map<string,vector<string> > m_response_headers;
         vector<string> m_saved_options;
-#ifdef HAVE_CURLINFO_TLS_SSL_PTR
+#if HAVE_DECL_CURLINFO_TLS_SSL_PTR
         bool m_cipherLogged;
 #endif
 #ifndef XMLTOOLING_NO_XMLSEC
@@ -257,7 +267,7 @@ namespace xmltooling {
     int XMLTOOL_DLLLOCAL verify_callback(X509_STORE_CTX* x509_ctx, void* arg);
 #endif
 
-    SOAPTransport* CURLSOAPTransportFactory(const SOAPTransport::Address& addr)
+    SOAPTransport* CURLSOAPTransportFactory(const SOAPTransport::Address& addr, bool deprecationSupport)
     {
         return new CURLSOAPTransport(addr);
     }
@@ -505,7 +515,7 @@ void CURLSOAPTransport::send(istream* in)
 
     // Setup standard per-call curl properties.
     curl_easy_setopt(m_handle,CURLOPT_DEBUGDATA,&log_curl);
-    curl_easy_setopt(m_handle,CURLOPT_FILE,&m_stream);
+    curl_easy_setopt(m_handle,CURLOPT_WRITEDATA,&m_stream);
     if (m_chunked && in) {
         curl_easy_setopt(m_handle,CURLOPT_POST,1);
         m_headers=curl_slist_append(m_headers,"Transfer-Encoding: chunked");
@@ -605,7 +615,7 @@ size_t xmltooling::curl_header_hook(void* ptr, size_t size, size_t nmemb, void*
 {
     CURLSOAPTransport* ctx = reinterpret_cast<CURLSOAPTransport*>(stream);
 
-#ifdef HAVE_CURLINFO_TLS_SSL_PTR
+#if HAVE_DECL_CURLINFO_TLS_SSL_PTR
     if (!ctx->m_cipherLogged) {
         Category& log = Category::getInstance(XMLTOOLING_LOGCAT ".SOAPTransport.CURL");
         if (log.isDebugEnabled()) {
@@ -711,20 +721,20 @@ int xmltooling::verify_callback(X509_STORE_CTX* x509_ctx, void* arg)
         ctx->m_criteria->setUsage(Credential::TLS_CREDENTIAL);
         // Bypass name check (handled for us by curl).
         ctx->m_criteria->setPeerName(nullptr);
-        success = ctx->m_trustEngine->validate(x509_ctx->cert,x509_ctx->untrusted,*(ctx->m_peerResolver),ctx->m_criteria);
+        success = ctx->m_trustEngine->validate(X509_STORE_CTX_get0_cert(x509_ctx),X509_STORE_CTX_get0_untrusted(x509_ctx),*(ctx->m_peerResolver),ctx->m_criteria);
     }
     else {
         // Bypass name check (handled for us by curl).
         CredentialCriteria cc;
         cc.setUsage(Credential::TLS_CREDENTIAL);
-        success = ctx->m_trustEngine->validate(x509_ctx->cert,x509_ctx->untrusted,*(ctx->m_peerResolver),&cc);
+        success = ctx->m_trustEngine->validate(X509_STORE_CTX_get0_cert(x509_ctx),X509_STORE_CTX_get0_untrusted(x509_ctx),*(ctx->m_peerResolver),&cc);
     }
 
     if (!success) {
         log.error("supplied TrustEngine failed to validate SSL/TLS server certificate");
-        if (x509_ctx->cert) {
+        if (X509_STORE_CTX_get0_cert(x509_ctx)) {
             BIO* b = BIO_new(BIO_s_mem());
-            X509_print(b, x509_ctx->cert);
+            X509_print(b, X509_STORE_CTX_get0_cert(x509_ctx));
             BUF_MEM* bptr = nullptr;
             BIO_get_mem_ptr(b, &bptr);
             if (bptr && bptr->length > 0) {
@@ -736,7 +746,7 @@ int xmltooling::verify_callback(X509_STORE_CTX* x509_ctx, void* arg)
             }
             BIO_free(b);
         }
-        x509_ctx->error = X509_V_ERR_APPLICATION_VERIFICATION;     // generic error, check log for plugin specifics
+        X509_STORE_CTX_set_error(x509_ctx, X509_V_ERR_APPLICATION_VERIFICATION);     // generic error, check log for plugin specifics
         ctx->setAuthenticated(false);
         return ctx->m_mandatory ? 0 : 1;
     }
