@@ -275,7 +275,11 @@ void CurlURLInputStream::init(const DOMElement* e)
     curl_easy_setopt(fEasy, CURLOPT_NOPROGRESS, 1);
     curl_easy_setopt(fEasy, CURLOPT_NOSIGNAL, 1);
     curl_easy_setopt(fEasy, CURLOPT_FAILONERROR, 1);
+#if HAVE_DECL_CURLOPT_ACCEPT_ENCODING
+    curl_easy_setopt(fEasy, CURLOPT_ACCEPT_ENCODING, "");
+#else
     curl_easy_setopt(fEasy, CURLOPT_ENCODING, "");
+#endif
 
     // Install SSL callback.
     curl_easy_setopt(fEasy, CURLOPT_SSL_CTX_FUNCTION, ssl_ctx_callback);
@@ -553,15 +557,22 @@ bool CurlURLInputStream::readMore(int* runningHandles)
 
         // Wait on the file descriptors
         timeval tv;
-        tv.tv_sec  = 2;
-        tv.tv_usec = 0;
+
+        long multi_timeout = 0;
+        curl_multi_timeout(fMulti, &multi_timeout);
+        if (multi_timeout < 0)
+            multi_timeout = 1000;
+
+        tv.tv_sec = multi_timeout / 1000;
+        tv.tv_usec = (multi_timeout % 1000) * 1000;
+
         select(fdcnt+1, &readSet, &writeSet, &exceptSet, &tv);
     }
 
     return curlResult == CURLM_CALL_MULTI_PERFORM;
 }
 
-xsecsize_t CurlURLInputStream::readBytes(XMLByte* const toFill, const xsecsize_t maxToRead)
+XMLSize_t CurlURLInputStream::readBytes(XMLByte* const toFill, const XMLSize_t maxToRead)
 {
     fBytesRead = 0;
     fBytesToRead = maxToRead;
